#!/bin/sh
if [ $# -ne 1 ]; then
    echo Usage: bootstrap.sh /path/to/platform
    echo Purpose: configure current directory to build for all cpus supported by platform
    exit 1
fi

set -e
PLATFORM=`cd $1; pwd` 

if test ! -f $PLATFORM/defs.sh.in; then
    echo "$PLATFORM doesn't appear to be a valid platform directory"
    exit 1
fi

SRCDIR=`pwd`

autoconf2.50
for cpu in ppc405 ppc750 sh4 i386; do
    for build in debug release; do
	ARCH=$cpu-$build
	if [ -f $PLATFORM/$ARCH/defs.sh ] ; then
	    ARCHES="$ARCHES $cpu-$build"
	    if [ \! -d $ARCH ]; then
		mkdir $ARCH
	    fi
	    needconfig=0
	    # Configure if never configured before
	    if test ! -f $ARCH/make.defs ; then
		    needconfig=1
	    else
		# Configure if any .in files newer than configure output
		deps=`find . -name '*.in' -newer $ARCH/make.defs -print`
		if test "$deps" != "" ; then
			needconfig=1
		fi
	    fi
	    if test $needconfig = 1; then
		. $PLATFORM/$ARCH/defs.sh

		cd $ARCH

		# Run configure, giving cross-compile tools and autoconf overrides in environment,
		# and specifying configure options needed by any configure script in all subdirs
		CC=${FOO_GCC3_CROSS_TOOL}gcc \
		CFLAGS="${FOO_TARGET_CFLAGS} -D_REENTRANT" \
		CXX=${FOO_GCC3_CROSS_TOOL}g++ \
		CXXFLAGS="${FOO_TARGET_CFLAGS} -D_REENTRANT" \
		LD=${FOO_CROSS_TOOL}ld \
		STRIP=${FOO_CROSS_TOOL}strip \
		AR=${FOO_CROSS_TOOL}ar \
		RANLIB=${FOO_CROSS_TOOL}ranlib \
		ac_cv_c_bigendian=${ac_cv_c_bigendian} \
		../configure \
		    --srcdir=$SRCDIR --with-ixplatform=$PLATFORM --build=pentium-unknown-linux \
		    --host=${FOO_K_ARCH}-unknown-linux --disable-snmp --enable-netlink
		cd ..
	    fi
	fi
    done
done

# generate top-level Makefile expanding 'all' into 'all-$ARCH'
rm -f Makefile
echo "default: all" >> Makefile
echo "include make.vars" >> Makefile
for ARCH in $ARCHES; do
    echo "include $ARCH/make.defs" >> Makefile
    echo "include $ARCH/make.rules" >> Makefile
done
for rule in all clean uninstall distclean; do
    echo -n "$rule: " >> Makefile
    echo "$ARCHES" | sed "s/ / ${rule}_/g" >> Makefile
done

# Generate wrapper Makefiles
perl bootstrap.pl
